package net.pricefx.common.apibuilder.contract;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

import net.pricefx.common.apibuilder.clicoll.LineItemHelper;

/**
 * A helper class that assists in manipulating the contract object.
 * Instance of this class can be obtained via call <code>cProcessor.getHelper()</code> from contract <a href="https://pricefx.atlassian.net/wiki/display/HELP/Header+Logics">header logic</a>.
 * <p><b>Recommended Reading:</b></p>
 * To understand how how calculation logics in contracts work please read article <a href="https://pricefx.atlassian.net/wiki/display/HELP/Contract+Calculation+Logic+Details">Contract Calculation Logic Details</a>.
 *
 * <p><b>Example:</b></p>
 * <blockquote><pre>
 *  def isHighPriority = cProcessor.getHelper().getRoot().getInputByName("IsHighPriority")?.value
 * </pre></blockquote>
 *
 * @see LineItemHelper
 */
public class ContractHelper extends LineItemHelper {

	public ContractHelper(Map<String, Object> calculableLineItemCollection) {
		super(calculableLineItemCollection);
	}

	/**
	 * Finds all contract line items with the specified contract term type.
	 * @param contractTermTypeUN unique name of contract term type
	 * @return list of line items {@link net.pricefx.common.apibuilder.clicoll.LineItemHelper.LineItem}
	 *
	 *
	 * <p>Example: </p>
	 * <blockquote><pre>
	 *  def lineItems = cProcessor.getHelper().findAllWithContractTermTypeUN("BundleUp")
	 *  lineItems.each { api.logInfo("line item label", it.label )}  // Bundle Up
	 * </pre></blockquote>
	 *
	 *
	 */
	@SuppressWarnings("unchecked")
	public List<LineItem> findAllWithContractTermTypeUN(String contractTermTypeUN) {
		ArrayList<LineItem> is = new ArrayList<>();
		for (Entry<String, Object> e : idToLineItem.entrySet()) {
			Map<String, Object> lineItemMap = (Map<String, Object>) e.getValue();
			if (contractTermTypeUN.equals(lineItemMap.get("contractTermType"))) {
				is.add(lineItemFromMap(lineItemMap));
			}
		}
		return is;
	}
	
}
