package net.pricefx.service;

import com.fasterxml.jackson.annotation.JsonFilter;
import net.pricefx.common.api.PriceFxInterface;
import net.pricefx.common.util.SpecialValue;

import java.util.*;

public class DMUtil {

	public static final String DB_SURROGATEKEY = "id";
	public static final String DB_DIRTYFLAG = "dirty";	// needed to rename from dirty as that already exists as a TINYINT column in existing tables	
	public static final String DB_CREATEDATE = PriceFxInterface.FIELD_CREATEDATE;
	public static final String DB_LASTUPDATEDATE = PriceFxInterface.FIELD_LASTUPDATEDATE;
	public static final String DB_ISDELETED = "isDeleted";	// important that this is the same name as for the PB domain objects
	public static final String DB_SOURCE = "source";
	public static final String DB_USER = "user";
	
	public static final char KEY_DELIMITER = '^';

	public interface DBValueSerializer {
		boolean include(FieldValues row);
		String serialize(String fieldName, final Object fieldValue);
	}

	
	public static String toString(final Object obj){
		if (obj instanceof String){
			return (String)obj;
		}
		else if (obj == null){
			return null;
		}
		else if (obj instanceof Date){
			return obj.toString();
		}
		else return obj.toString();
	}


	public int compareDates( Date date, Date otherDate ){
		if (date == null && otherDate  == null) return 0;
		else if (date == null && otherDate != null) return -1;
		else if (date != null && otherDate == null) return +1;
		else return date.compareTo(otherDate);
	}
	
	
	///////////////////////////////////////////////////////////////////////////////////////////////////////
	// Helper types
	//
	
	public static boolean isNull(final Object value){
		return SpecialValue.isNull(value);
	}


	public static interface Key extends Comparable<Key> {

		@Override
		public int compareTo(Key o);

		public boolean hasNulls();
	}

	@JsonFilter("DynamicFieldFilter")
	public static abstract class FieldValues extends LinkedHashMap<String,Object> {
	}

}
